@@ -3,7 +3,6 @@ import sys
 
 import pep440
 import pytest
-from mock import patch
 
 import setupmeta
 import setupmeta.versioning
@@ -13,8 +12,11 @@ from setupmeta.scm import Version
 from . import conftest
 
 
+patch = conftest.mock.patch
+
+
 def new_meta(versioning, name="just-testing", scm=None, setup_py=None, **kwargs):
-    setup_py = setup_py or conftest.resouce("setup.py")
+    setup_py = setup_py or conftest.resource("setup.py")
     upstream = dict(versioning=versioning, scm=scm, _setup_py_path=setup_py)
     if name:
         # Allow to test "missing name" case
@@ -324,6 +326,15 @@ def test_malformed():
         assert "WARNING: 'name' not specified in setup.py" in logged
 
 
+def test_custom_version_tag():
+    with conftest.capture_output():
+        meta = new_meta(dict(main="distance", extra="", version_tag="v*.*"), scm=conftest.MockGit())
+        versioning = meta.versioning
+        assert versioning.strategy.version_tag == "v*.*"
+        assert versioning.scm.version_tag == "v*.*"
+        assert str(versioning.scm.get_version()) == "v0.1.2-3-g123"
+
+
 def test_distance_marker():
     with conftest.capture_output():
         meta = new_meta("{major}.{minor}.{distance}", scm=conftest.MockGit())
